@@ -5,6 +5,11 @@ if sys.maxsize > 2 ** 32:
     import LocalAuthentication
 
     class TestLAContext (TestCase):
+        def testConstants(self):
+            self.assertEqual(LocalAutentication.LABiometryTypeNone, 0)
+            self.assertEqual(LocalAutentication.LABiometryNone, 0)
+            self.assertEqual(LocalAutentication.LABiometryTypeTouchID, 1)
+
         @min_os_level("10.10")
         def testClasses(self):
             self.assertIsInstance(LocalAuthentication.LAContext, objc.objc_class)
@@ -22,6 +27,13 @@ if sys.maxsize > 2 ** 32:
             self.assertResultIsBOOL(LocalAuthentication.LAContext.isFallbackButtonVisible)
             self.assertArgIsBOOL(LocalAuthentication.LAContext.setFallbackButtonVisible_, 0)
 
+        @min_os_level("10.13")
+        def testMethods(self):
+            self.assertArgIsBOOL(LocalAuthentication.LAContext.setInteractionNotAllowed_, 0)
+            self.assertResultIsBOOL(LocalAuthentication.LAContext.interactionNotAllowed)
+
+            #self.assertArgIsBlock(LocalAuthentication.LAContext.withCurrentContextExecute_queue_, 0, b"v")
+
         @min_os_level("10.10")
         def testConstants(self):
             self.assertEqual(LocalAuthentication.LAPolicyDeviceOwnerAuthenticationWithBiometrics,
